==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/polymer/entity/WildPigImpl.java <==
package cc.thonly.polymer.entity;

import cc.thonly.mystias_izakaya.entity.WildPigEntity;
import cc.thonly.reverie_dreams.mixin.accessor.PigEntityAccessor;
import eu.pb4.polymer.core.api.entity.PolymerEntity;
import net.minecraft.class_10586;
import net.minecraft.class_1299;
import net.minecraft.class_2378;
import net.minecraft.class_2945;
import net.minecraft.class_3222;
import net.minecraft.class_5455;
import net.minecraft.class_6880;
import net.minecraft.class_7924;
import net.minecraft.server.MinecraftServer;
import xyz.nucleoid.packettweaker.PacketContext;

import java.util.List;

public record WildPigImpl(WildPigEntity wildPig) implements PolymerEntity {

    @Override
    public class_1299<?> getPolymerEntityType(PacketContext context) {
        return class_1299.field_6093;
    }

    @Override
    public void modifyRawTrackedData(List<class_2945.class_7834<?>> data, class_3222 player, boolean initial) {
        PolymerEntity.super.modifyRawTrackedData(data, player, initial);
        if (initial && !this.wildPig.method_37908().field_9236) {
            MinecraftServer server = this.wildPig.method_5682();
            assert server != null;
            class_5455.class_6890 registryManager = server.method_30611();
            class_2378<class_10586> registry = registryManager.method_30530(class_7924.field_55883);
            class_6880<class_10586> pigVariant = registry.method_47983(registry.method_29107(WildPigEntity.VARIANT));

            class_2945.class_7834<class_6880<class_10586>> entry = class_2945.class_7834.method_46360(
                    PigEntityAccessor.VARIANT(),
                    pigVariant);

            data.add(entry);

        }
    }
}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/polymer/entity/WildPigImpl.java <==
package cc.thonly.polymer.entity;

import cc.thonly.reverie_dreams.entity.WildPigEntity;
import cc.thonly.reverie_dreams.mixin.accessor.PigEntityAccessor;
import eu.pb4.polymer.core.api.entity.PolymerEntity;
import net.minecraft.class_10586;
import net.minecraft.class_1299;
import net.minecraft.class_2378;
import net.minecraft.class_2945;
import net.minecraft.class_3222;
import net.minecraft.class_5455;
import net.minecraft.class_6880;
import net.minecraft.class_7924;
import net.minecraft.server.MinecraftServer;
import xyz.nucleoid.packettweaker.PacketContext;

import java.util.List;

public record WildPigImpl(WildPigEntity wildPig) implements PolymerEntity {

    @Override
    public class_1299<?> getPolymerEntityType(PacketContext context) {
        return class_1299.field_6093;
    }

    @Override
    public void modifyRawTrackedData(List<class_2945.class_7834<?>> data, class_3222 player, boolean initial) {
        PolymerEntity.super.modifyRawTrackedData(data, player, initial);
        if (initial && !this.wildPig.method_37908().field_9236) {
            MinecraftServer server = this.wildPig.method_5682();
            assert server != null;
            class_5455.class_6890 registryManager = server.method_30611();
            class_2378<class_10586> registry = registryManager.method_30530(class_7924.field_55883);
            class_6880<class_10586> pigVariant = registry.method_47983(registry.method_29107(WildPigEntity.VARIANT));

            class_2945.class_7834<class_6880<class_10586>> entry = class_2945.class_7834.method_46360(
                    PigEntityAccessor.VARIANT(),
                    pigVariant);

            data.add(entry);

        }
    }
}
